PyDIAMONDS
==========

PyDIAMONDS was created to provide python bindings for the bayesian inference software DIAMONDS. It provides an easy way
to access the fast underlying C++ code in python. For a deeper documentation visit
https://github.com/EnricoCorsaro/DIAMONDS, where you can find the C++ code.

Installation
------------

PyDIAMONDS is provided through pypi. Simply call::

    pip install pyDiamonds

to install the package. Be sure to have a full cmake toolchain as well as clang/gcc on your machine to build the code.

Documentation
-------------

The documentation of the classes available to python will be more and more implemented over time. See the docs folder
for documentation. For a more exhaustive documentation visit https://github.com/EnricoCorsaro/DIAMONDS where you can
find a more exhaustive documentation on DIAMONDS. Various examples can also be found in the examples folder.
